"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MMSImage = void 0;
const AbstractImageMessage_1 = require("../AbstractImageMessage");
/**
 * Represents an image message for the MMS channel.
 *
 * @group MMS
 */
class MMSImage extends AbstractImageMessage_1.AbstractImageMessage {
    /**
     * Send an MMS image message.
     *
     * @param {MessageParamsImage} params - The parameters for creating the image message.
     * @example
     * ```ts
     * import { MMSImage } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new MMSImage({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  image: {
     *    url: 'https://example.com/image.jpg',
     *    caption: 'This is an example image',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.channel = 'mms';
    }
}
exports.MMSImage = MMSImage;
