import { AbstractFileMessage } from '../AbstractFileMessage';
import { MessageParams, MessengerFileParams } from '../../types';
/**
 * Represents a file message for the Messenger channel.
 *
 * @group Messenger
 */
export declare class MessengerFile extends AbstractFileMessage implements MessengerFileParams, MessageParams {
    /**
     * The channel for this message (always 'messenger').
     */
    channel: 'messenger';
    /**
     * The messenger information for this message.
     */
    messenger: import("../../types").MessengerType;
    /**
     * Sends a file message to the Facebook Messenger channel.
     *
     * @param {MessengerFileParams} params - The parameters for creating a Messenger file message.
     *
     * @example
     * ```ts
     * import { MessengerFile } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new MessengerFile({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  file: {
     *    url: 'https://example.com/image.jpg',
     *    caption: 'This is an image',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params: MessageParams & MessengerFileParams);
}
