"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessengerFile = void 0;
const AbstractFileMessage_1 = require("../AbstractFileMessage");
/**
 * Represents a file message for the Messenger channel.
 *
 * @group Messenger
 */
class MessengerFile extends AbstractFileMessage_1.AbstractFileMessage {
    /**
     * Sends a file message to the Facebook Messenger channel.
     *
     * @param {MessengerFileParams} params - The parameters for creating a Messenger file message.
     *
     * @example
     * ```ts
     * import { MessengerFile } from '@vonage/messages';
     *
     * const { messageUUID } = await messagesClient.send(new MessengerFile({
     *  to: TO_NUMBER,
     *  from: FROM_NUMBER,
     *  file: {
     *    url: 'https://example.com/image.jpg',
     *    caption: 'This is an image',
     *  },
     *  clientRef: 'my-personal-reference',
     * }));
     *
     * console.log(`Message sent successfully with UUID ${messageUUID}`);
     * ```
     */
    constructor(params) {
        super(params);
        this.messenger = params.messenger;
        this.channel = 'messenger';
    }
}
exports.MessengerFile = MessengerFile;
